<?php

/**
 * @file
 * Theme settings for the sasson
 */
function sasson_form_system_theme_settings_alter(&$form, &$form_state) {
  
  $form['#submit'] = array('drupal_theme_rebuild', 'sasson_clear_cache');
  
  /**
   * Development Settings
   */
  $form['sasson_development'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Development'),
  );
  $form['sasson_development']['sasson_clear_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page request.'),
    '#description' => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#default_value' => theme_get_setting('sasson_clear_registry'),
  );
  $form['sasson_development']['sasson_show_grid'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show grid background layer.'),
    '#description' => t('Display a visible background grid, for easier elements positioning'),
    '#default_value' => theme_get_setting('sasson_show_grid'),
  );  
  /**
   * SASS Settings
   */
  $form['sasson_sass'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('SASS / SCSS'),
  );
  $form['sasson_sass']['sasson_sass'] = array(
    '#type' => 'checkbox',
    '#title' => t('Compile SASS / SCSS to CSS'),
    '#description' => t('SASS integration - uncheck if you are already using a different sass compiler.'),
    '#default_value' => theme_get_setting('sasson_sass'),
  );
  $form['sasson_sass']['sasson_devel'] = array(
    '#type' => 'checkbox',
    '#title' => t('Development mode - Recompile all SASS / SCSS files on every change (+FireSass support).'),
    '#description' => t('SASS Development - Recompile SASS / SCSS files every time you change them and get <a href="!link">FireSass</a> support. WARNING: css output is way bigger, use only in development.', array('!link' => 'https://addons.mozilla.org/en-US/firefox/addon/firesass-for-firebug/')),
    '#default_value' => theme_get_setting('sasson_devel'),
  );
  $form['sasson_sass']['sasson_flush'] = array(
    '#type' => 'submit',
    '#value' => 'Recompile SASS / SCSS files',
    '#submit' => array('sasson_clear_cache'),
  );
  /**
   * HTML5 Settings
   */
  $form['sasson_html5'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('HTML5 support'),
  );
  $form['sasson_html5']['sasson_force_ie'] = array(
    '#type' => 'checkbox',
    '#title' => t('Always force latest IE rendering engine (even in intranet) & Chrome Frame'),
    '#default_value' => theme_get_setting('sasson_force_ie'),
  );
  $form['sasson_html5']['sasson_html5shiv'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable HTML5 elements in IE'),
    '#description' => t('Makes IE understand HTML5 elements via <a href="!shivlink">HTML5 shiv</a>. disable if you use a different method.', array('!shivlink' => 'http://code.google.com/p/html5shiv/')),
    '#default_value' => theme_get_setting('sasson_html5shiv'),
  );
  /**
   * Grid Settings
   */
  $form['sasson_grid'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Grid settings'),
  );
  $form['sasson_grid']['sasson_grid_width'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Grid width'),
    '#description' => t("Set the total grid width"),
    '#default_value' => theme_get_setting('sasson_grid_width'),
  );
  $form['sasson_grid']['sasson_columns'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Number of columns'),
    '#description' => t("Set the total number of columns"),
    '#default_value' => theme_get_setting('sasson_columns'),
  );
  $form['sasson_grid']['sasson_gutter_width'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Gutter width'),
    '#description' => t("This value represents the margin betwwen grid elements"),
    '#default_value' => theme_get_setting('sasson_gutter_width'),
  );
  $form['sasson_grid']['sasson_sidebar_first'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('First sidebar width'),
    '#description' => t("Set the width (# of columns) for the first sidebar"),
    '#default_value' => theme_get_setting('sasson_sidebar_first'),
  );
  $form['sasson_grid']['sasson_sidebar_second'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Second sidebar width'),
    '#description' => t("Set the width (# of columns) for the second sidebar"),
    '#default_value' => theme_get_setting('sasson_sidebar_second'),
  );
  /**
   * Responsive Layout Settings
   */
  $form['sasson_layout'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Responsive Layout'),
  );
  $form['sasson_layout']['sasson_responsive'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable responsive layout'),
    '#description' => t("Disable if you don't want your site layout to adapt to small devices"),
    '#default_value' => theme_get_setting('sasson_responsive'),
  );
  $form['sasson_layout']['sasson_responsive_approach'] = array(
    '#type' => 'radios',
    '#title' => t('Desktop or Mobile first'),
    '#options' => array(
        'desktop_first' => t('Desktop first'),
        'mobile_first' => t('Mobile first'),
      ),
    '#description' => t('Select an approach for your responsive layout. desktop-first means we start with desktop size page and reduce accordingly, mobile-first means we start with a very simple layout and build on top of that.'),
    '#default_value' => theme_get_setting('sasson_responsive_approach'),
  );
  $form['sasson_layout']['desktop-first'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Desktop first'),
  );
  $form['sasson_layout']['desktop-first']['sasson_responsive_narrow'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Narrow width'),
    '#description' => t("Set the first breakpoint in which the layout will adapt, this should probably be your max page width"),
    '#default_value' => theme_get_setting('sasson_responsive_narrow'),
  );
  $form['sasson_layout']['desktop-first']['sasson_responsive_narrower'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Narrower width'),
    '#description' => t("Set the second breakpoint in which the layout will adapt"),
    '#default_value' => theme_get_setting('sasson_responsive_narrower'),
  );
  $form['sasson_layout']['desktop-first']['sasson_responsive_narrowest'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Narrowest width'),
    '#description' => t("Set the third breakpoint in which the layout will adapt"),
    '#default_value' => theme_get_setting('sasson_responsive_narrowest'),
  );
  $form['sasson_layout']['mobile-first'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Mobile first'),
  );
$form['sasson_layout']['mobile-first']['sasson_responsive_mf_small'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Small width'),
    '#description' => t("Set the first breakpoint in which the layout will adapt"),
    '#default_value' => theme_get_setting('sasson_responsive_mf_small'),
  );
  $form['sasson_layout']['mobile-first']['sasson_responsive_mf_medium'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Medium width'),
    '#description' => t("Set the second breakpoint in which the layout will adapt"),
    '#default_value' => theme_get_setting('sasson_responsive_mf_medium'),
  );
  $form['sasson_layout']['mobile-first']['sasson_responsive_mf_large'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Large width'),
    '#description' => t("Set the third breakpoint in which the layout will adapt, this should probably be your max page width"),
    '#default_value' => theme_get_setting('sasson_responsive_mf_large'),
  );
  $form['sasson_layout']['responsive_menus'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Responsive menus'),
  );
  $form['sasson_layout']['responsive_menus']['sasson_responsive_menus_width'] = array(
    '#type' => 'textfield',
    '#size' => 10,
    '#title' => t('Responsive menus page width'),
    '#description' => t("Set the width in which the selected menus turn into a select menu, or 0 to disable."),
    '#default_value' => theme_get_setting('sasson_responsive_menus_width'),
  );
  $form['sasson_layout']['responsive_menus']['sasson_responsive_menus_selectors'] = array(
    '#type' => 'textfield',
    '#title' => t('Responsive menus selectors'),
    '#description' => t("Enter some CSS selectors for the menus you want to alter."),
    '#default_value' => theme_get_setting('sasson_responsive_menus_selectors'),
  );
  /**
   * General Settings
   */
  $form['sasson_general'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('General'),
  );
  $form['sasson_general']['sasson_breadcrumb_hideonlyfront'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide the breadcrumb if the breadcrumb only contains the link to the front page.'),
    '#default_value' => theme_get_setting('sasson_breadcrumb_hideonlyfront'),
  );
  
  $form['sasson_general']['sasson_breadcrumb_showtitle'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show page title on breadcrumb.'),
    '#default_value' => theme_get_setting('sasson_breadcrumb_showtitle'),
  );

  $form['sasson_general']['sasson_breadcrumb_separator'] = array(
    '#type' => 'textfield',
    '#title' => t('Breadcrumb separator'),
    '#default_value' => theme_get_setting('sasson_breadcrumb_separator'),
  );
  $form['sasson_general']['sasson_feed_icons'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display Feed Icons'),
    '#default_value' => theme_get_setting('sasson_feed_icons'),
  );
}

/**
 * Deletes old cached SCSS files.
 */
function sasson_clear_cache() {
  variable_del('sasson_cache');
  file_scan_directory('public://sasson', '/.*/', array('callback' => 'drupal_delete_file_if_stale'));
}
